# 1 LLT001 {: #LLT001 }

Reference: doorstop/core/test/test_document.py (line 187)

*Links:* [REQ003](REQ.html#REQ003)

# 2 LLT002 {: #LLT002 }

Reference: doorstop/core/test/test_all.py (line 544)

*Links:* [REQ004](REQ.html#REQ004)

# 3 LLT003 {: #LLT003 }

Reference: doorstop/core/test/test_all.py (line 517)

*Links:* [REQ007](REQ.html#REQ007)

# 4 LLT004 {: #LLT004 }

Reference: doorstop/core/test/test_document.py (line 120)

*Links:* [REQ008](REQ.html#REQ008)

# 5 LLT005 {: #LLT005 }

Reference: doorstop/core/test/test_item.py (line 399)

*Links:* [REQ001](REQ.html#REQ001)

# 6 LLT007 {: #LLT007 }

**Inspection Tests**

These checks ensure the version control system (VCS) meets the needs of requirements management:

- Verify the VCS includes a 'tag' feature.
- Verify the VCS stores files in a permanent and secure manner.
- Verify the VCS handles change management of files.
- Verify the VCS associates changes to existing developer acccounts.
- Verify the VCS can manage changes to thousands of files.

*Links:* [REQ009](REQ.html#REQ009), [REQ011](REQ.html#REQ011), [REQ012](REQ.html#REQ012), [REQ013](REQ.html#REQ013), [REQ014](REQ.html#REQ014), [REQ015](REQ.html#REQ015)

# 7 LLT008 {: #LLT008 }

**Inspection Tests**

These checks ensure the Python package is distributed properly:

- Verify the installation can be performed on a new computer in fewer than 10 seconds.

*Links:* [REQ015](REQ.html#REQ015)

